from .config import Config, InvalidConfig, Setup
from .helpers import ynq, pwd_prompt, login
from .commands import Day, Help, Grade
from .lang import write
from librusapi.exceptions import TokenExpiredError
from librusapi import Token
from sys import argv


def main():
    config = Config()
    try:
        config.load()
    except FileNotFoundError:
        write("Config file not found.", fore="LIGHTRED_EX")
        write("Entering setup...")
        setup = Setup()
        setup.begin()
        config = setup.config
    except TokenExpiredError:
        write("Token expired.")
        config = login(config.username, pwd_prompt(), config)
        if config:
            write("Success!", fore="GREEN", style="BRIGHT")
        else:
            write("Failed!", fore="RED")
            exit(1)
    except Exception as ex:
        write("An unknown error has occurred!", fore="RED")
        write(ex)
        if ynq("Would you like to delete your config file?"):
            config.destroy()

    commands = {"day": Day(), "help": Help(), "grade": Grade()}
    if len(argv) > 1 and argv[1] in commands:
        try:
            commands[argv[1]].token = config.token
            commands[argv[1]].parse(argv[2:])
        except TokenExpiredError:
            config = login(config.username, pwd_prompt(), config)
            if config:
                write("Success!", fore="GREEN", style="BRIGHT")
                commands[argv[1]].token = config.token
                commands[argv[1]].parse(argv[2:])
            else:
                write("Failed!", fore="RED")
                exit(1)
