from . import Command
from ..lang import flavor_text, write as fwrite
from librusapi import Timetable, Token
from datetime import datetime, timedelta
from prettytable import PrettyTable


class Day(Command):
    """
    All things concering the 'day' command.
    """

    def __init__(self):
        super().__init__()
        fields = (
            flavor_text("Starts", fore="YELLOW", style="BRIGHT"),
            flavor_text("Name", fore="CYAN", style="BRIGHT"),
            flavor_text("Flag", fore="RED", style="BRIGHT"),
        )
        self.table = PrettyTable(fields)
        self.weekdayabbr = ""

    def write(self):
        fwrite(self.weekdayabbr, fore="BLUE", bg="BLACK", style="BRIGHT")
        print(self.table)

    def parse(self, argv):
        self.datastore = []
        timetable = Timetable(self.token)
        if len(argv) == 1:
            relative_day = argv[0]
        else:
            relative_day = 0
        try:
            relative_day = int(relative_day)
        except (ValueError, TypeError):
            print(f"'{relative_day}' is not a valid number")
            exit(1)

        chosen_day = datetime.now() + timedelta(days=relative_day)
        self.weekdayabbr = chosen_day.strftime("%A")

        for lesson in timetable.get(chosen_day):
            if lesson.start.weekday() == chosen_day.weekday():
                self.datastore.append(lesson)
                row = (
                    flavor_text(lesson.start.strftime("%H:%M"), fore="YELLOW"),
                    flavor_text(lesson.name, fore="CYAN"),
                    flavor_text(lesson.flag, fore="RED")
                    if lesson.flag
                    else flavor_text("-", fore="GREEN"),
                )
                self.table.add_row(row)
        self.write()
