from os import path, remove, makedirs
from json import load, dump
from librusapi.exceptions import TokenExpiredError
from librusapi import Token


class InvalidConfig(Exception):
    """Raised when username is empty."""

    pass


class Config:

    """
    Manages your config store.
    """

    def __init__(self):
        self.username = None
        self.token = None
        self.path = path.expanduser("~/.config/libruscli/config.json")

    def load(self):
        """
        Loads config from disk.
        """
        with open(self.path, "r", encoding="utf-8") as cfg:
            json = load(cfg)
            self.username = json.get("username")
            self.token = json.get("token")
            if not self.token and not self.token.get("client"):
                self.token = None
                raise TokenExpiredError
            else:
                self.token = Token(self.token.get("client"))

    def write(self):
        """
        Writes config to disk.
        """
        if not self.username:
            raise InvalidConfig
        makedirs(path.dirname(self.path), exist_ok=True)
        with open(self.path, "w", encoding="utf-8") as cfg:
            dump(self.__dict__, cfg, default=lambda o: o.__dict__)

    def destroy(self):
        """
        Deletes config from disk.
        """
        remove(self.path)
